<?php
/*
 * Elementor Fame Banner Widget
 * Author & Copyright: VictorTheme
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Fame_Banner extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'vt-fame_banner';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Banner', 'fame-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-picture-o';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['victortheme-category'];
	}

	/**
	 * Retrieve the list of scripts the Fame Banner widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	/*
	public function get_script_depends() {
		return ['vt-fame_banner'];
	}
	*/
	
	/**
	 * Register Fame Banner widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_banner',
			[
				'label' => __( 'Banner Options', 'fame-core' ),
			]
		);
		$this->add_control(
			'banner_style',
			[
				'label' => esc_html__( 'Banner Style', 'fame-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__( 'Style One', 'fame-core' ),
					'style-two' => esc_html__( 'Style Two', 'fame-core' ),
				],
				'default' => 'style-one',
				'description' => esc_html__( 'Select your banner style.', 'fame-core' ),
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => esc_html__( 'Background Image', 'fame-core' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'fame-core'),
			]
		);
		$this->add_control(
			'banner_image',
			[
				'label' => esc_html__( 'Banner Image', 'fame-core' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'fame-core'),
			]
		);
		$this->add_control(
			'retina_img',
			[
				'label' => esc_html__( 'Retina Banner Image?', 'fame-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'fame-core' ),
				'label_off' => esc_html__( 'No', 'fame-core' ),
				'return_value' => 'true',
				'description' => esc_html__( 'If you want to resize your retina image, enable it.', 'fame-core' ),
			]
		);
		$this->add_responsive_control(
			'custom_max_height',
			[
				'label' => esc_html__( 'Custom Max Height', 'fame-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1500,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .fame-banner .fame-image img' => 'max-height: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'retina_img' => 'true',
				],
			]
		);
		$this->add_control(
			'banner_title',
			[
				'label' => esc_html__( 'Title Text', 'fame-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title Text', 'fame-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'fame-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'banner_subtitle',
			[
				'label' => esc_html__( 'Sub Title', 'fame-core' ),
				'default' => esc_html__( 'your content text', 'fame-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'fame-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);

		$this->end_controls_section();// end: Section

		$this->start_controls_section(
			'section_banner_btn',
			[
				'label' => esc_html__( 'Button Options', 'fame-core' ),
			]
		);
		$this->add_control(
			'btn_style',
			[
				'label' => esc_html__( 'Button/Link Style', 'fame-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__( 'Style One (Button)', 'fame-core' ),
					'style-two' => esc_html__( 'Style Two (Video)', 'fame-core' ),
				],
				'default' => 'style-one',
				'description' => esc_html__( 'Select your button style.', 'fame-core' ),
			]
		);
		$this->add_control(
			'banner_btn',
			[
				'label' => esc_html__( 'Button Text', 'fame-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Button Text', 'fame-core' ),
				'placeholder' => esc_html__( 'Type btn text here', 'fame-core' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'video_link',
			[
				'label' => esc_html__( 'Video Link', 'fame-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'default' => esc_html__( 'This is video link', 'fame-core' ),
				'placeholder' => esc_html__( 'Enter your link here', 'fame-core' ),	
				'condition' => [
					'btn_style' => array('style-two'),
				],			
			]
		);
		$this->add_control(
			'banner_btn_link',
			[
				'label' => esc_html__( 'Button Link', 'fame-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
				'condition' => [
					'btn_style' => array('style-one'),
				],
			]
		);
		$this->add_control(
			'banner_btn_icon',
			[
				'label' => esc_html__( 'Icon', 'fame-core' ),
				'type' => Controls_Manager::ICON,
				'options' => Controls_Helper_Output::get_include_icons(),
				'frontend_available' => true,
				'default' => 'fa fa-play',
				'condition' => [
					'btn_style' => array('style-two'),
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Style
		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'fame-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'fame-core' ),
				'name' => 'sasban_title_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .caption-wrap h1',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'fame-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .caption-wrap h1' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();// end: Section

		// Sub Title		
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__( 'Sub Title', 'fame-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'label' => esc_html__( 'Typography', 'fame-core' ),
					'name' => 'subtitle_typography',
					'scheme' => Scheme_Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .caption-wrap h4',
				]
			);
			$this->add_control(
				'subtitle_color',
				[
					'label' => esc_html__( 'Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .caption-wrap h4' => 'color: {{VALUE}};',
					],
				]
			);
		$this->end_controls_section();// end: Section

		// Video		
		$this->start_controls_section(
			'section_video_style',
			[
				'label' => esc_html__( 'Button Style', 'fame-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'btn_style' => array('style-two'),
				],
			]
		);		
		$this->start_controls_tabs( 'icon_style' );
			$this->start_controls_tab(
				'icon_normal',
				[
					'label' => esc_html__( 'Normal', 'fame-core' ),
				]
			);
			$this->add_control(
				'vbtn_text_color',
				[
					'label' => esc_html__( 'Text Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fame-video-btn-wrap .video-btn-title' => 'color: {{VALUE}};',
						'{{WRAPPER}} .fame-video-btn-wrap .video-btn-title:after' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'vbtn_icon_color',
				[
					'label' => esc_html__( 'Icon Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fame-video-btn-wrap .fame-video-btn' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'vbtn_icon_bg_color',
				[
					'label' => esc_html__( 'Button Background Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fame-video-btn-wrap .fame-video-btn' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'vbtn_icon_border_color',
				[
					'label' => esc_html__( 'Button Border Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fame-video-btn-wrap .fame-video-btn:before, {{WRAPPER}} .fame-video-btn-wrap .fame-video-btn:after' => 'border-color: {{VALUE}};',
					],
				]
			);
			$this->end_controls_tab();  // end:Normal tab
			
			$this->start_controls_tab(
				'icon_hover',
				[
					'label' => esc_html__( 'Hover', 'fame-core' ),
				]
			);
			$this->add_control(
				'vbtn_text_hover_color',
				[
					'label' => esc_html__( 'Icon Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fame-video-btn-wrap:hover .video-btn-title' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'vbtn_icon_hover_color',
				[
					'label' => esc_html__( 'Icon Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fame-video-btn-wrap:hover .fame-video-btn' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'vbtn_icon_bg_hover_color',
				[
					'label' => esc_html__( 'Button Background Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fame-video-btn-wrap:hover .fame-video-btn' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'vbtn_icon_border_hover_color',
				[
					'label' => esc_html__( 'Button Border Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fame-video-btn-wrap:hover .fame-video-btn:before, {{WRAPPER}} .fame-video-btn-wrap:hover .fame-video-btn:after' => 'border-color: {{VALUE}};',
					],
				]
			);
			$this->end_controls_tab();  // end:Hover tab
		$this->end_controls_tabs(); // end tabs
		$this->end_controls_section();// end: Section

		// Button
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__( 'Button Style', 'fame-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'btn_style' => array('style-one'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .caption-wrap .fame-btn',
			]
		);
		$this->add_responsive_control(
			'button_min_width',
			[
				'label' => esc_html__( 'Width', 'fame-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 500,
						'step' => 1,
					],
				],
				'size_units' => [ 'px' ],
				'selectors' => [
					'{{WRAPPER}} .caption-wrap .fame-btn' => 'min-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'button_padding',
			[
				'label' => __( 'Padding', 'fame-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .caption-wrap .fame-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'button_border_radius',
			[
				'label' => __( 'Border Radius', 'fame-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .caption-wrap .fame-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->start_controls_tabs( 'button_style' );
			$this->start_controls_tab(
				'button_normal',
				[
					'label' => esc_html__( 'Normal', 'fame-core' ),
				]
			);
			$this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .caption-wrap .fame-btn' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'button_bg_color',
				[
					'label' => esc_html__( 'Background Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .caption-wrap .fame-btn' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'button_border',
					'label' => esc_html__( 'Border', 'fame-core' ),
					'selector' => '{{WRAPPER}} .caption-wrap .fame-btn',
				]
			);
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'btn_box_shadow',
					'label' => esc_html__( 'Button Box Shadow', 'fame-core' ),
					'selector' => '{{WRAPPER}} .caption-wrap .fame-btn',
				]
			);
			$this->end_controls_tab();  // end:Normal tab
			
			$this->start_controls_tab(
				'button_hover',
				[
					'label' => esc_html__( 'Hover', 'fame-core' ),
				]
			);
			$this->add_control(
				'button_hover_color',
				[
					'label' => esc_html__( 'Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .caption-wrap .fame-btn:hover' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'button_bg_hover_color',
				[
					'label' => esc_html__( 'Background Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .caption-wrap .fame-btn:hover' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'button_hover_border',
					'label' => esc_html__( 'Border', 'fame-core' ),
					'selector' => '{{WRAPPER}} .caption-wrap .fame-btn:hover',
				]
			);
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'btn_hover_box_shadow',
					'label' => esc_html__( 'Button Box Shadow', 'fame-core' ),
					'selector' => '{{WRAPPER}} .caption-wrap .fame-btn:hover',
				]
			);
			$this->end_controls_tab();  // end:Hover tab
		$this->end_controls_tabs(); // end tabs
		
		$this->end_controls_section();// end: Section
		
	}

	/**
	 * Render App Works widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		$settings = $this->get_settings_for_display();
		$banner_style = !empty( $settings['banner_style'] ) ? $settings['banner_style'] : '';	
		$bg_image = !empty( $settings['bg_image']['id'] ) ? $settings['bg_image']['id'] : '';	
		$banner_image = !empty( $settings['banner_image']['id'] ) ? $settings['banner_image']['id'] : '';	
		$retina_img = !empty( $settings['retina_img'] ) ? $settings['retina_img'] : '';
		$banner_title = !empty( $settings['banner_title'] ) ? $settings['banner_title'] : '';	
		$banner_subtitle = !empty( $settings['banner_subtitle'] ) ? $settings['banner_subtitle'] : '';	

		$btn_style = !empty( $settings['btn_style'] ) ? $settings['btn_style'] : '';	
		$banner_btn = !empty( $settings['banner_btn'] ) ? $settings['banner_btn'] : '';	
		$video_link = !empty( $settings['video_link'] ) ? $settings['video_link'] : '';	
		$banner_btn_link = !empty( $settings['banner_btn_link']['url'] ) ? $settings['banner_btn_link']['url'] : '';
		$banner_btn_link_external = !empty( $settings['banner_btn_link']['is_external'] ) ? 'target="_blank"' : '';
		$banner_btn_link_nofollow = !empty( $settings['banner_btn_link']['nofollow'] ) ? 'rel="nofollow"' : '';
		$banner_btn_link_attr = !empty( $banner_btn_link ) ?  $banner_btn_link_external.' '.$banner_btn_link_nofollow : '';

		$banner_btn_icon = !empty( $settings['banner_btn_icon'] ) ? $settings['banner_btn_icon'] : '';	

		// Image
		$image_url = wp_get_attachment_url( $bg_image );
		$banner_image_url = wp_get_attachment_url( $banner_image );

		$title = $banner_title ? '<h1 class="caption-title">'.$banner_title.'</h1>' : '';
		$sub_title = $banner_subtitle ? '<h4 class="caption-subtitle">'.$banner_subtitle.'</h4>' : '';

		$icon = $banner_btn_icon ? '<span class="fame-video-btn"><i class="'.$banner_btn_icon.'" aria-hidden="true"></i></span>' : '';
		$video_btn = $banner_btn ? '<span class="video-btn-title">'.$banner_btn.'</span>' : '';
		
		if($btn_style === 'style-two') {
		  $button = $video_link ? '<div class="fame-video-link"><a href="'.$video_link.'" class="fame-video-btn-wrap fame-popup-video">'.$icon.$video_btn.'</a></div>' : '';
		} else {
		  $button = $banner_btn_link ? '<div class="fame-btn-wrap"><a href="'.$banner_btn_link.'" '.$banner_btn_link_attr.' class="fame-btn">'.$banner_btn.'</a></div>' : '';
		}

		$image = $banner_image ? '<div class="fame-image"><img src="'.$banner_image_url.'" alt="Banner"></div>' : '';

		if($banner_style === 'style-two') {
			$output = '<div class="fame-banner banner-style-two" style="background-image: url('.$image_url.');">
						      <div class="fame-table-wrap">
						        <div class="fame-align-wrap">
						          <div class="container">
						            <div class="row">
						              <div class="col-md-8">
						                <div class="caption-wrap">'.$sub_title.$title.$button.'</div>
						              </div>
						              <div class="col-md-4">
						                <div class="banner-image">'.$image.'</div>
						              </div>
						            </div>
						          </div>
						        </div>
						      </div>
						    </div>';
		} else {
			$output = '<div class="fame-banner" style="background-image: url('.$image_url.');">
								  <div class="fame-table-wrap">
								    <div class="fame-align-wrap">
								      <div class="container">
								        <div class="row align-items-center">
								          <div class="col-md-8">
								            <div class="caption-wrap">'.$sub_title.$title.$button.'</div>
								          </div>
								          <div class="col-md-4">'.$image.'</div>
								        </div>
								      </div>
								    </div>
								  </div>
								</div>';
		}
		echo $output;
		
	}

	/**
	 * Render Banner widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Fame_Banner() );