<?php
/*
 * Elementor Fame Screen Detail Widget
 * Author & Copyright: VictorTheme
*/

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Fame_ScreenDetail extends Widget_Base{

	/**
	 * Retrieve the widget name.
	*/
	public function get_name(){
		return 'vt-fame_screen_detail';
	}

	/**
	 * Retrieve the widget title.
	*/
	public function get_title(){
		return esc_html__( 'Screen Detail', 'fame-core' );
	}

	/**
	 * Retrieve the widget icon.
	*/
	public function get_icon() {
		return 'fa fa-window-restore';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	*/
	public function get_categories() {
		return ['victortheme-category'];
	}

	/**
	 * Retrieve the list of scripts the Fame Screen Detail widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	*/
	/*
	public function get_script_depends() {
		return ['vt-fame_screen_detail'];
	}
	*/
	
	/**
	 * Register Fame Screen Detail widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	*/
	protected function _register_controls(){
		
		$this->start_controls_section(
			'section_screen_detail',
			[
				'label' => __( 'Screen Detail Left Item', 'fame-core' ),
			]
		);

		$repeater = new Repeater();
		$repeater->add_control(
			'icon_type',
			[
				'label' => __( 'Icon Type', 'fame-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'image' => esc_html__( 'Image', 'fame-core' ),
					'icon' => esc_html__( 'Icon', 'fame-core' ),
				],
				'default' => 'image',
			]
		);
		$repeater->add_control(
			'screen_detail_icon',
			[
				'label' => esc_html__( 'Icon', 'fame-core' ),
				'type' => Controls_Manager::ICON,
				'options' => Controls_Helper_Output::get_include_icons(),
				'frontend_available' => true,
				'default' => 'icon-arrows-check',
				'condition' => [
					'icon_type' => 'icon',
				],
			]
		);
		$repeater->add_control(
			'screen_detail_image',
			[
				'label' => esc_html__( 'Upload Icon', 'fame-core' ),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'icon_type' => 'image',
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your icon image.', 'fame-core'),
			]
		);
		
		$repeater->add_control(
			'screen_detail_title',
			[
				'label' => esc_html__( 'Title', 'fame-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title', 'fame-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'fame-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'screen_detail_title_link',
			[
				'label' => esc_html__( 'Link', 'fame-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'screen_detail_content',
			[
				'label' => esc_html__( 'Content', 'fame-core' ),
				'default' => esc_html__( 'your content text', 'fame-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'fame-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'screen_detail_groups',
			[
				'label' => esc_html__( 'Screen Detail Items', 'fame-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'screen_detail_title' => esc_html__( 'Easy to Use', 'fame-core' ),
						'screen_detail_content' => esc_html__( 'The road and back again your heart is true your be where you can travelled down the road.', 'fame-core' ),
					],
					
				],
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ screen_detail_title }}}',
			]
		);
		
		$this->end_controls_section();// end: Section

		$this->start_controls_section(
			'section_center',
			[
				'label' => __( 'Screen Center Image', 'fame-core' ),
			]
		);
		$this->add_control(
			'screen_center_image',
			[
				'label' => esc_html__( 'Center Image', 'fame-core' ),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your image.', 'fame-core'),
			]
		);
		$this->add_responsive_control(
			'custom_max_width',
			[
				'label' => esc_html__( 'Custom Max Width', 'fame-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1500,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .fame-image .fame-image-wrap img' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'bg_color',
			[
				'label' => esc_html__( 'Background Pulse Color', 'fame-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fame-image-animation:before, {{WRAPPER}} .fame-image-animation:after, {{WRAPPER}} .fame-image-wrap:before' => 'background-color: {{VALUE}};',
				],
			]
		);	
		$this->end_controls_section();// end: Section

		$this->start_controls_section(
			'section_screen_detail_right',
			[
				'label' => __( 'Screen Detail Right Item', 'fame-core' ),
			]
		);

		$repeaterOne = new Repeater();
		$repeaterOne->add_control(
			'icon_type_right',
			[
				'label' => __( 'Icon Type', 'fame-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'image' => esc_html__( 'Image', 'fame-core' ),
					'icon' => esc_html__( 'Icon', 'fame-core' ),
				],
				'default' => 'image',
			]
		);
		$repeaterOne->add_control(
			'screen_detail_right_icon',
			[
				'label' => esc_html__( 'Icon', 'fame-core' ),
				'type' => Controls_Manager::ICON,
				'options' => Controls_Helper_Output::get_include_icons(),
				'frontend_available' => true,
				'default' => 'icon-arrows-check',
				'condition' => [
					'icon_type_right' => 'icon',
				],
			]
		);
		$repeaterOne->add_control(
			'screen_detail_right_image',
			[
				'label' => esc_html__( 'Upload Icon', 'fame-core' ),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'icon_type_right' => 'image',
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__( 'Set your icon image.', 'fame-core'),
			]
		);
		
		$repeaterOne->add_control(
			'screen_detail_right_title',
			[
				'label' => esc_html__( 'Title', 'fame-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title', 'fame-core' ),
				'placeholder' => esc_html__( 'Type title text here', 'fame-core' ),
				'label_block' => true,
			]
		);
		$repeaterOne->add_control(
			'screen_detail_right_title_link',
			[
				'label' => esc_html__( 'Link', 'fame-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		$repeaterOne->add_control(
			'screen_detail_right_content',
			[
				'label' => esc_html__( 'Content', 'fame-core' ),
				'default' => esc_html__( 'your content text', 'fame-core' ),
				'placeholder' => esc_html__( 'Type your content here', 'fame-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'screen_detail_right_groups',
			[
				'label' => esc_html__( 'Screen Detail Items', 'fame-core' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'screen_detail_right_title' => esc_html__( 'Easy to Use', 'fame-core' ),
						'screen_detail_right_content' => esc_html__( 'The road and back again your heart is true your be where you can travelled down the road.', 'fame-core' ),
					],
					
				],
				'fields' => $repeaterOne->get_controls(),
				'title_field' => '{{{ screen_detail_right_title }}}',
			]
		);
		
		$this->end_controls_section();// end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'fame-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'label' => esc_html__( 'Typography', 'fame-core' ),
					'name' => 'sastool_title_typography',
					'scheme' => Scheme_Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .screen-info-item h3',
				]
			);
			$this->start_controls_tabs( 'screen_detail_title_style' );
				$this->start_controls_tab(
					'title_normal',
					[
						'label' => esc_html__( 'Normal', 'fame-core' ),
					]
				);
				$this->add_control(
					'title_color',
					[
						'label' => esc_html__( 'Color', 'fame-core' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .screen-info-item h3, {{WRAPPER}} .screen-info-item h3 a' => 'color: {{VALUE}};',
						],
					]
				);
				$this->end_controls_tab();  // end:Normal tab
				
				$this->start_controls_tab(
					'title_hover',
					[
						'label' => esc_html__( 'Hover', 'fame-core' ),
					]
				);
				$this->add_control(
					'title_hov_color',
					[
						'label' => esc_html__( 'Color', 'fame-core' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .screen-info-item h3 a:hover' => 'color: {{VALUE}};',
						],
					]
				);
				$this->end_controls_tab();  // end:Hover tab
			$this->end_controls_tabs(); // end tabs
		$this->end_controls_section();// end: Section
		
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'fame-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'label' => esc_html__( 'Typography', 'fame-core' ),
					'name' => 'content_typography',
					'scheme' => Scheme_Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .screen-info-item p',
				]
			);
			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Color', 'fame-core' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .screen-info-item p' => 'color: {{VALUE}};',
					],
				]
			);
		$this->end_controls_section();// end: Section

		$this->start_controls_section(
			'icon_style',
			[
				'label' => esc_html__( 'Icon', 'fame-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Color', 'fame-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .screen-info-item .fame-icon i' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'icon_font_size',
			[
				'label' => esc_html__( 'Icon Font Size', 'fame-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 200,
						'step' => 1,
					],
				],
				'size_units' => [ 'px' ],
				'selectors' => [
					'{{WRAPPER}} .screen-info-item .fame-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();// end: Section
		
	}

	/**
	 * Render Screen Detail widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	*/
	protected function render() {
		// Screen Detail query
		$settings = $this->get_settings_for_display();
		$screen_detail = $this->get_settings_for_display( 'screen_detail_groups' );
		$screen_detail_right = $this->get_settings_for_display( 'screen_detail_right_groups' );
		$center_image = !empty( $settings['screen_center_image']['id'] ) ? $settings['screen_center_image']['id'] : '';	
		$center_image_url = wp_get_attachment_url( $center_image );
	  $center_img = $center_image_url ? '<div class="fame-image-wrap"><img src="'. $center_image_url .'" alt="Device"></div>' : '';

		$output = '<div class="fame-screen-detail">
							  <div class="container">
							    <div class="row align-items-center">
							      <div class="col-md-4">';
											// Group Param Output
											foreach ( $screen_detail as $each_logo ) {
												$image_url = wp_get_attachment_url( $each_logo['screen_detail_image']['id'], 'thumbnail' );
												$fame_alt = get_post_meta($each_logo['screen_detail_image']['id'], '_wp_attachment_image_alt', true);
												$screen_detail_title_link = !empty( $each_logo['screen_detail_title_link'] ) ? $each_logo['screen_detail_title_link'] : '';
												$link_url = !empty( $screen_detail_title_link['url'] ) ? esc_url($screen_detail_title_link['url']) : '';
												$link_external = !empty( $screen_detail_title_link['is_external'] ) ? 'target="_blank"' : '';
												$link_nofollow = !empty( $screen_detail_title_link['nofollow'] ) ? 'rel="nofollow"' : '';
												$link_attr = !empty( $screen_detail_title_link['url'] ) ?  $link_external.' '.$link_nofollow : '';

												$icon_type = !empty( $each_logo['icon_type'] ) ? $each_logo['icon_type'] : '';
									  		$icon = !empty( $each_logo['screen_detail_icon'] ) ? $each_logo['screen_detail_icon'] : '';

											  $title_link = !empty( $link_url ) ? '<a href="'.$link_url.'" '.$link_attr.'>'.$each_logo['screen_detail_title'].'</a>' : $each_logo['screen_detail_title'];
										  	$title = !empty( $each_logo['screen_detail_title'] ) ? '<h3 class="screen-info-title">'.$title_link.'</h3>' : '';
											  $content = !empty( $each_logo['screen_detail_content'] ) ? '<p>'.$each_logo['screen_detail_content'].'</p>' : '';

											  $image = $image_url ? '<div class="fame-icon"><img src="'. $image_url .'" width="64" alt="'.$fame_alt.'"></div>' : '';
												$icon = $icon ? '<div class="fame-icon"><i class="'.$icon.'" aria-hidden="true"></i></div>' : '';

											  if($icon_type === 'icon') {
												  $icon_image = $icon;
												} else {
												  $icon_image = $image;
												}

											  $output .= '<div class="screen-info-item">'.$icon_image.$title.$content.'</div>';
											}						        
	      $output .= '</div>
							      <div class="col-md-4 text-center">
							        <div class="fame-image fame-image-animation">'.$center_img.'</div>
							      </div>
							      <div class="col-md-4 text-right">';
							      	// Group Param Output Right
											foreach ( $screen_detail_right as $each_logo_right ) {
												$image_url_right = wp_get_attachment_url( $each_logo_right['screen_detail_right_image']['id'], 'thumbnail' );
												$fame_alt_right = get_post_meta($each_logo_right['screen_detail_right_image']['id'], '_wp_attachment_image_alt', true);
												$screen_detail_right_title_link = !empty( $each_logo_right['screen_detail_right_title_link'] ) ? $each_logo_right['screen_detail_right_title_link'] : '';
												$link_url_right = !empty( $screen_detail_right_title_link['url'] ) ? esc_url($screen_detail_right_title_link['url']) : '';
												$link_external_right = !empty( $screen_detail_right_title_link['is_external'] ) ? 'target="_blank"' : '';
												$link_nofollow_right = !empty( $screen_detail_right_title_link['nofollow'] ) ? 'rel="nofollow"' : '';
												$link_attr_right = !empty( $screen_detail_right_title_link['url'] ) ?  $link_external_right.' '.$link_nofollow_right : '';

												$icon_type_right = !empty( $each_logo_right['icon_type_right'] ) ? $each_logo_right['icon_type_right'] : '';
									  		$icon_right = !empty( $each_logo_right['screen_detail_right_icon'] ) ? $each_logo_right['screen_detail_right_icon'] : '';

											  $title_link_right = !empty( $link_url_right ) ? '<a href="'.$link_url_right.'" '.$link_attr_right.'>'.$each_logo_right['screen_detail_right_title'].'</a>' : $each_logo_right['screen_detail_right_title'];
										  	$title_right = !empty( $each_logo_right['screen_detail_right_title'] ) ? '<h3 class="screen-info-title">'.$title_link_right.'</h3>' : '';
											  $content_right = !empty( $each_logo_right['screen_detail_right_content'] ) ? '<p>'.$each_logo_right['screen_detail_right_content'].'</p>' : '';

											  $image_right = $image_url_right ? '<div class="fame-icon"><img src="'. $image_url_right .'" width="64" alt="'.$fame_alt_right.'"></div>' : '';
												$icon_right = $icon_right ? '<div class="fame-icon"><i class="'.$icon_right.'" aria-hidden="true"></i></div>' : '';

											  if($icon_type_right === 'icon') {
												  $icon_right_image = $icon_right;
												} else {
												  $icon_right_image = $image_right;
												}

											  $output .= '<div class="screen-info-item">'.$icon_right_image.$title_right.$content_right.'</div>';
											}							        
	      $output .= '</div>
							    </div>
							  </div>
							</div>';	

		echo $output;
		
	}

	/**
	 * Render Screen Detail widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	*/
	
	//protected function _content_template(){}
	
}
Plugin::instance()->widgets_manager->register_widget_type( new Fame_ScreenDetail() );