<?php

/**
 * Initialize Custom Post Type - Fame Theme
 */
function fame_custom_post_type() {
	$noneed_portfolio_post = (fame_framework_active()) ? cs_get_option('noneed_portfolio_post') : '';
	$noneed_case_studies_post = (fame_framework_active()) ? cs_get_option('noneed_case_studies_post') : '';
	$noneed_testimonial_post = (fame_framework_active()) ? cs_get_option('noneed_testimonial_post') : '';
	$noneed_team_post = (fame_framework_active()) ? cs_get_option('noneed_team_post') : '';

	if (!$noneed_portfolio_post) {
		// Portfolio
		$portfolio_cpt = (fame_framework_active()) ? cs_get_option('theme_portfolio_name') : '';
		$portfolio_slug = (fame_framework_active()) ? cs_get_option('theme_portfolio_slug') : '';
		$portfolio_cpt_slug = (fame_framework_active()) ? cs_get_option('theme_portfolio_cat_slug') : '';

		$base = (isset($portfolio_cpt_slug) && $portfolio_cpt_slug !== '') ? sanitize_title_with_dashes($portfolio_cpt_slug) : ((isset($portfolio_cpt) && $portfolio_cpt !== '') ? strtolower($portfolio_cpt) : 'portfolio');
		$base_slug = (isset($portfolio_slug) && $portfolio_slug !== '') ? sanitize_title_with_dashes($portfolio_slug) : ((isset($portfolio_cpt) && $portfolio_cpt !== '') ? strtolower($portfolio_cpt) : 'portfolio');
		$label = ucfirst((isset($portfolio_cpt) && $portfolio_cpt !== '') ? strtolower($portfolio_cpt) : 'portfolio');

		// Register custom post type - Portfolio
		register_post_type('portfolio',
			array(
				'labels' => array(
					'name' => $label,
					'singular_name' => sprintf(esc_html__('%s Post', 'fame-core' ), $label),
					'all_items' => sprintf(esc_html__('All %s', 'fame-core' ), $label),
					'add_new' => esc_html__('Add New', 'fame-core') ,
					'add_new_item' => sprintf(esc_html__('Add New %s', 'fame-core' ), $label),
					'edit' => esc_html__('Edit', 'fame-core') ,
					'edit_item' => sprintf(esc_html__('Edit %s', 'fame-core' ), $label),
					'new_item' => sprintf(esc_html__('New %s', 'fame-core' ), $label),
					'view_item' => sprintf(esc_html__('View %s', 'fame-core' ), $label),
					'search_items' => sprintf(esc_html__('Search %s', 'fame-core' ), $label),
					'not_found' => esc_html__('Nothing found in the Database.', 'fame-core') ,
					'not_found_in_trash' => esc_html__('Nothing found in Trash', 'fame-core') ,
					'parent_item_colon' => ''
				) ,
				'public' => true,
				'publicly_queryable' => true,
				'exclude_from_search' => false,
				'show_ui' => true,
				'query_var' => true,
				'menu_position' => 20,
				'menu_icon' => 'dashicons-admin-appearance',
				'rewrite' => array(
					'slug' => $base_slug,
					'with_front' => false
				),
				'has_archive' => true,
				'capability_type' => 'post',
				'hierarchical' => true,
				'supports' => array(
					'title',
					'editor',
					'author',
					'thumbnail',
					'excerpt',
					'trackbacks',
					'custom-fields',
					'comments',
					'revisions',
					'sticky',
					'page-attributes'
				)
			)
		);
		// Registered

		// Add Category Taxonomy for our Custom Post Type - Portfolio
		register_taxonomy(
			'portfolio_category',
			'portfolio',
			array(
				'hierarchical' => true,
				'public' => true,
				'show_ui' => true,
				'show_admin_column' => true,
				'show_in_nav_menus' => true,
				'labels' => array(
					'name' => sprintf(esc_html__( '%s Categories', 'fame-core' ), $label),
					'singular_name' => sprintf(esc_html__('%s Category', 'fame-core'), $label),
					'search_items' =>  sprintf(esc_html__( 'Search %s Categories', 'fame-core'), $label),
					'all_items' => sprintf(esc_html__( 'All %s Categories', 'fame-core'), $label),
					'parent_item' => sprintf(esc_html__( 'Parent %s Category', 'fame-core'), $label),
					'parent_item_colon' => sprintf(esc_html__( 'Parent %s Category:', 'fame-core'), $label),
					'edit_item' => sprintf(esc_html__( 'Edit %s Category', 'fame-core'), $label),
					'update_item' => sprintf(esc_html__( 'Update %s Category', 'fame-core'), $label),
					'add_new_item' => sprintf(esc_html__( 'Add New %s Category', 'fame-core'), $label),
					'new_item_name' => sprintf(esc_html__( 'New %s Category Name', 'fame-core'), $label)
				),
				'rewrite' => array( 'slug' => $base . '_cat' ),
			)
		);

		$args = array(
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud' => false,
		);
	}

	if (!$noneed_case_studies_post) {
		// Case Studies
		$case_studies_cpt = (fame_framework_active()) ? cs_get_option('theme_case_studies_name') : '';
		$case_studies_slug = (fame_framework_active()) ? cs_get_option('theme_case_studies_slug') : '';
		$case_studies_cpt_slug = (fame_framework_active()) ? cs_get_option('theme_case_studies_cat_slug') : '';

		$case_base = (isset($case_studies_cpt_slug) && $case_studies_cpt_slug !== '') ? sanitize_title_with_dashes($case_studies_cpt_slug) : ((isset($case_studies_cpt) && $case_studies_cpt !== '') ? strtolower($case_studies_cpt) : 'casestudies');
		$case_base_slug = (isset($case_studies_slug) && $case_studies_slug !== '') ? sanitize_title_with_dashes($case_studies_slug) : ((isset($case_studies_cpt) && $case_studies_cpt !== '') ? strtolower($case_studies_cpt) : 'casestudies');
		$case_label = ucfirst((isset($case_studies_cpt) && $case_studies_cpt !== '') ? strtolower($case_studies_cpt) : 'Case Studies');

		// Register custom post type - Case Studies
		register_post_type('casestudies',
			array(
				'labels' => array(
					'name' => $case_label,
					'singular_name' => sprintf(esc_html__('%s Post', 'fame-core' ), $case_label),
					'all_items' => sprintf(esc_html__('All %s', 'fame-core' ), $case_label),
					'add_new' => esc_html__('Add New', 'fame-core') ,
					'add_new_item' => sprintf(esc_html__('Add New %s', 'fame-core' ), $case_label),
					'edit' => esc_html__('Edit', 'fame-core') ,
					'edit_item' => sprintf(esc_html__('Edit %s', 'fame-core' ), $case_label),
					'new_item' => sprintf(esc_html__('New %s', 'fame-core' ), $case_label),
					'view_item' => sprintf(esc_html__('View %s', 'fame-core' ), $case_label),
					'search_items' => sprintf(esc_html__('Search %s', 'fame-core' ), $case_label),
					'not_found' => esc_html__('Nothing found in the Database.', 'fame-core') ,
					'not_found_in_trash' => esc_html__('Nothing found in Trash', 'fame-core') ,
					'parent_item_colon' => ''
				) ,
				'public' => true,
				'publicly_queryable' => true,
				'exclude_from_search' => false,
				'show_ui' => true,
				'query_var' => true,
				'menu_position' => 20,
				'menu_icon' => 'dashicons-portfolio',
				'rewrite' => array(
					'slug' => $case_base_slug,
					'with_front' => false
				),
				'has_archive' => true,
				'capability_type' => 'post',
				'hierarchical' => true,
				'supports' => array(
					'title',
					'editor',
					'author',
					'thumbnail',
					'excerpt',
					'trackbacks',
					'custom-fields',
					'comments',
					'revisions',
					'sticky',
					'page-attributes'
				)
			)
		);
		// Registered

		// Add Category Taxonomy for our Custom Post Type - Case Studies
		register_taxonomy(
			'casestudies_category',
			'casestudies',
			array(
				'hierarchical' => true,
				'public' => true,
				'show_ui' => true,
				'show_admin_column' => true,
				'show_in_nav_menus' => true,
				'labels' => array(
					'name' => sprintf(esc_html__( '%s Categories', 'fame-core' ), $case_label),
					'singular_name' => sprintf(esc_html__('%s Category', 'fame-core'), $case_label),
					'search_items' =>  sprintf(esc_html__( 'Search %s Categories', 'fame-core'), $case_label),
					'all_items' => sprintf(esc_html__( 'All %s Categories', 'fame-core'), $case_label),
					'parent_item' => sprintf(esc_html__( 'Parent %s Category', 'fame-core'), $case_label),
					'parent_item_colon' => sprintf(esc_html__( 'Parent %s Category:', 'fame-core'), $case_label),
					'edit_item' => sprintf(esc_html__( 'Edit %s Category', 'fame-core'), $case_label),
					'update_item' => sprintf(esc_html__( 'Update %s Category', 'fame-core'), $case_label),
					'add_new_item' => sprintf(esc_html__( 'Add New %s Category', 'fame-core'), $case_label),
					'new_item_name' => sprintf(esc_html__( 'New %s Category Name', 'fame-core'), $case_label)
				),
				'rewrite' => array( 'slug' => $case_base . '_cat' ),
			)
		);

		$args = array(
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud' => false,
		);
	}

	if (!$noneed_testimonial_post) {
		// Testimonials - Start
		$testimonial_cpt = (fame_framework_active()) ? cs_get_option('theme_testimonial_name') : '';
		$testimonial_slug = (fame_framework_active()) ? cs_get_option('theme_testimonial_slug') : '';
		$testimonial_cpt_slug = (fame_framework_active()) ? cs_get_option('theme_testimonial_cat_slug') : '';

		$testi_base = (isset($testimonial_cpt_slug) && $testimonial_cpt_slug !== '') ? sanitize_title_with_dashes($testimonial_cpt_slug) : ((isset($testimonial_cpt) && $testimonial_cpt !== '') ? strtolower($testimonial_cpt) : 'testimonial');
		$testi_base_slug = (isset($testimonial_slug) && $testimonial_slug !== '') ? sanitize_title_with_dashes($testimonial_slug) : ((isset($testimonial_cpt) && $testimonial_cpt !== '') ? strtolower($testimonial_cpt) : 'testimonial');
		$testi_label = ucfirst((isset($testimonial_cpt) && $testimonial_cpt !== '') ? strtolower($testimonial_cpt) : 'testimonial');

		// Register custom post type - Testimonials
		register_post_type('testimonial',
			array(
				'labels' => array(
					'name' => $testi_label,
					'singular_name' => sprintf(esc_html__('%s Post', 'fame-core' ), $testi_label),
					'all_items' => sprintf(esc_html__('%s', 'fame-core' ), $testi_label),
					'add_new' => esc_html__('Add New', 'fame-core') ,
					'add_new_item' => sprintf(esc_html__('Add New %s', 'fame-core' ), $testi_label),
					'edit' => esc_html__('Edit', 'fame-core') ,
					'edit_item' => sprintf(esc_html__('Edit %s', 'fame-core' ), $testi_label),
					'new_item' => sprintf(esc_html__('New %s', 'fame-core' ), $testi_label),
					'view_item' => sprintf(esc_html__('View %s', 'fame-core' ), $testi_label),
					'search_items' => sprintf(esc_html__('Search %s', 'fame-core' ), $testi_label),
					'not_found' => esc_html__('Nothing found in the Database.', 'fame-core'),
					'not_found_in_trash' => esc_html__('Nothing found in Trash', 'fame-core'),
					'parent_item_colon' => ''
				) ,
				'public' => true,
				'publicly_queryable' => true,
				'exclude_from_search' => false,
				'show_ui' => true,
				'query_var' => true,
				'menu_position' => 23,
				'menu_icon' => 'dashicons-groups',
				'rewrite' => array(
					'slug' => $testi_base_slug,
					'with_front' => false
				),
				'has_archive' => true,
				'capability_type' => 'post',
				'hierarchical' => true,
				'supports' => array(
					'title',
					'editor',
					'excerpt',
					'thumbnail',
					'revisions',
					'sticky',
					'page-attributes'
				)
			)
		);

		// Add Category Taxonomy for our Custom Post Type - Webinars
		register_taxonomy(
			'testimonial_category',
			'testimonial',
			array(
				'hierarchical' => true,
				'public' => true,
				'show_ui' => true,
				'show_admin_column' => true,
				'show_in_nav_menus' => true,
				'labels' => array(
					'name' => sprintf(esc_html__( '%s Categories', 'fame-core' ), $testi_label),
					'singular_name' => sprintf(esc_html__('%s Category', 'fame-core'), $testi_label),
					'search_items' =>  sprintf(esc_html__( 'Search %s Categories', 'fame-core'), $testi_label),
					'all_items' => sprintf(esc_html__( 'All %s Categories', 'fame-core'), $testi_label),
					'parent_item' => sprintf(esc_html__( 'Parent %s Category', 'fame-core'), $testi_label),
					'parent_item_colon' => sprintf(esc_html__( 'Parent %s Category:', 'fame-core'), $testi_label),
					'edit_item' => sprintf(esc_html__( 'Edit %s Category', 'fame-core'), $testi_label),
					'update_item' => sprintf(esc_html__( 'Update %s Category', 'fame-core'), $testi_label),
					'add_new_item' => sprintf(esc_html__( 'Add New %s Category', 'fame-core'), $testi_label),
					'new_item_name' => sprintf(esc_html__( 'New %s Category Name', 'fame-core'), $testi_label)
				),
				'rewrite' => array( 'slug' => $testi_base_slug . '_cat' ),
			)
		);

		$args = array(
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud' => false,
		);
		// Testimonials - End
	}
	if (!$noneed_team_post) {
		// Team Start
		$team_cpt = (fame_framework_active()) ? cs_get_option('theme_team_name') : '';
		$team_slug = (fame_framework_active()) ? cs_get_option('theme_team_slug') : '';
		$team_cpt_slug = (fame_framework_active()) ? cs_get_option('theme_team_cat_slug') : '';

		$team_base = (isset($team_cpt_slug) && $team_cpt_slug !== '') ? sanitize_title_with_dashes($team_cpt_slug) : ((isset($team_cpt) && $team_cpt !== '') ? strtolower($team_cpt) : 'team');
		$team_base_slug = (isset($team_slug) && $team_slug !== '') ? sanitize_title_with_dashes($team_slug) : ((isset($team_cpt) && $team_cpt !== '') ? strtolower($team_cpt) : 'team');
		$teams = ucfirst((isset($team_cpt) && $team_cpt !== '') ? strtolower($team_cpt) : 'team');

		// Register custom post type - Team
		register_post_type('team',
			array(
				'labels' => array(
					'name' => $teams,
					'singular_name' => sprintf(esc_html__('%s Post', 'fame-core' ), $teams),
					'all_items' => sprintf(esc_html__('%s', 'fame-core' ), $teams),
					'add_new' => esc_html__('Add New', 'fame-core') ,
					'add_new_item' => sprintf(esc_html__('Add New %s', 'fame-core' ), $teams),
					'edit' => esc_html__('Edit', 'fame-core') ,
					'edit_item' => sprintf(esc_html__('Edit %s', 'fame-core' ), $teams),
					'new_item' => sprintf(esc_html__('New %s', 'fame-core' ), $teams),
					'view_item' => sprintf(esc_html__('View %s', 'fame-core' ), $teams),
					'search_items' => sprintf(esc_html__('Search %s', 'fame-core' ), $teams),
					'not_found' => esc_html__('Nothing found in the Database.', 'fame-core') ,
					'not_found_in_trash' => esc_html__('Nothing found in Trash', 'fame-core') ,
					'parent_item_colon' => ''
				) ,
				'public' => true,
				'publicly_queryable' => true,
				'exclude_from_search' => false,
				'show_ui' => true,
				'query_var' => true,
				'menu_position' => 24,
				'menu_icon' => 'dashicons-businessman',
				'rewrite' => array(
					'slug' => $team_base_slug,
					'with_front' => false
				),
				'has_archive' => true,
				'capability_type' => 'post',
				'hierarchical' => true,
				'supports' => array(
					'title',
					'editor',
					'thumbnail',
					'excerpt',
					'revisions',
					'sticky',
					'page-attributes'
				)
			)
		);

		register_taxonomy(
			'team_category',
			'team',
			array(
				'hierarchical' => true,
				'public' => true,
				'show_ui' => true,
				'show_admin_column' => true,
				'show_in_nav_menus' => true,
				'labels' => array(
					'name' => sprintf(esc_html__( '%s Categories', 'fame-core' ), $teams),
					'singular_name' => sprintf(esc_html__('%s Category', 'fame-core'), $teams),
					'search_items' =>  sprintf(esc_html__( 'Search %s Categories', 'fame-core'), $teams),
					'all_items' => sprintf(esc_html__( 'All %s Categories', 'fame-core'), $teams),
					'parent_item' => sprintf(esc_html__( 'Parent %s Category', 'fame-core'), $teams),
					'parent_item_colon' => sprintf(esc_html__( 'Parent %s Category:', 'fame-core'), $teams),
					'edit_item' => sprintf(esc_html__( 'Edit %s Category', 'fame-core'), $teams),
					'update_item' => sprintf(esc_html__( 'Update %s Category', 'fame-core'), $teams),
					'add_new_item' => sprintf(esc_html__( 'Add New %s Category', 'fame-core'), $teams),
					'new_item_name' => sprintf(esc_html__( 'New %s Category Name', 'fame-core'), $teams)
				),
				'rewrite' => array( 'slug' => $team_base_slug . '_cat' ),
			)
		);

		$args = array(
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud' => false,
		);
		// Team - End
	}

}

function fame_custom_posttype_slug() {
	$noneed_portfolio_post = (fame_framework_active()) ? cs_get_option('noneed_portfolio_post') : '';
	$noneed_case_studies_post = (fame_framework_active()) ? cs_get_option('noneed_case_studies_post') : '';
	$noneed_testimonial_post = (fame_framework_active()) ? cs_get_option('noneed_testimonial_post') : '';
	$noneed_team_post = (fame_framework_active()) ? cs_get_option('noneed_team_post') : '';
	if (!$noneed_portfolio_post) {
		// Portfolio Post
		$portfolio_cpt = (fame_framework_active()) ? cs_get_option('theme_portfolio_name') : '';
		if ($portfolio_cpt === '') $portfolio_cp = 'portfolio';
	  $rules = get_option( 'rewrite_rules' );
	  if ( ! isset( $rules['('.$portfolio_cpt.')/(\d*)$'] ) ) {
			global $wp_rewrite;
			$wp_rewrite->flush_rules();
	  }
	}
	if (!$noneed_case_studies_post) {
		// Case Studies Post
		$case_studies_cpt = (fame_framework_active()) ? cs_get_option('theme_case_studies_name') : '';
		if ($case_studies_cpt === '') $case_studies_cp = 'casestudies';
	  $rules = get_option( 'rewrite_rules' );
	  if ( ! isset( $rules['('.$case_studies_cpt.')/(\d*)$'] ) ) {
			global $wp_rewrite;
			$wp_rewrite->flush_rules();
	  }
	}
	if (!$noneed_testimonial_post) {
	  // Testimonial Post
	  $testimonial_cpt = (fame_framework_active()) ? cs_get_option('theme_testimonial_name') : '';
		if ($testimonial_cpt === '') $testimonial_cp = 'testimonial';
	  $rules = get_option( 'rewrite_rules' );
	  if ( ! isset( $rules['('.$testimonial_cpt.')/(\d*)$'] ) ) {
			global $wp_rewrite;
			$wp_rewrite->flush_rules();
	  }
	}
	if (!$noneed_team_post) {
	  // Team Post
	  $team_cpt = (fame_framework_active()) ? cs_get_option('theme_team_name') : '';
		if ($team_cpt === '') $team_cp = 'team';
	  $rules = get_option( 'rewrite_rules' );
	  if ( ! isset( $rules['('.$team_cpt.')/(\d*)$'] ) ) {
			global $wp_rewrite;
			$wp_rewrite->flush_rules();
	  }
	}
}
add_action( 'cs_validate_save_after','fame_custom_posttype_slug' );

// After Theme Setup
function fame_custom_flush_rules() {
	// Enter post type function, so rewrite work within this function
	fame_custom_post_type();
	// Flush it
	flush_rewrite_rules();
}
register_activation_hook(__FILE__, 'fame_custom_flush_rules');
add_action('init', 'fame_custom_post_type');

// Avoid portfolio post type as 404 page while it change
function vt_cpt_avoid_error_posttype() {
	$noneed_portfolio_post = (fame_framework_active()) ? cs_get_option('noneed_portfolio_post') : '';
	$noneed_case_studies_post = (fame_framework_active()) ? cs_get_option('noneed_case_studies_post') : '';
	$noneed_testimonial_post = (fame_framework_active()) ? cs_get_option('noneed_testimonial_post') : '';
	$noneed_team_post = (fame_framework_active()) ? cs_get_option('noneed_team_post') : '';
	if (!$noneed_portfolio_post) {
		// Portfolio Post
		$portfolio_cpt = (fame_framework_active()) ? cs_get_option('theme_portfolio_name') : '';
		if ($portfolio_cpt === '') $portfolio_cp = 'portfolio';
		$set = get_option('post_type_rules_flased_' . $portfolio_cpt);
		if ($set !== true){
			flush_rewrite_rules(false);
			update_option('post_type_rules_flased_' . $portfolio_cpt,true);
		}
	}
	if (!$noneed_case_studies_post) {
		// Case Studies Post
		$case_studies_cpt = (fame_framework_active()) ? cs_get_option('theme_case_studies_name') : '';
		if ($case_studies_cpt === '') $case_studies_cp = 'casestudies';
		$set = get_option('post_type_rules_flased_' . $case_studies_cpt);
		if ($set !== true){
			flush_rewrite_rules(false);
			update_option('post_type_rules_flased_' . $case_studies_cpt,true);
		}
	}
	if (!$noneed_testimonial_post) {
		// Testimonial Post
		$testimonial_cpt = (fame_framework_active()) ? cs_get_option('theme_testimonial_name') : '';
		if ($testimonial_cpt === '') $testimonial_cp = 'testimonial';
		$set = get_option('post_type_rules_flased_' . $testimonial_cpt);
		if ($set !== true){
			flush_rewrite_rules(false);
			update_option('post_type_rules_flased_' . $testimonial_cpt,true);
		}
	}
	if (!$noneed_team_post) {
		// Team Post
		$team_cpt = (fame_framework_active()) ? cs_get_option('theme_team_name') : '';
		if ($team_cpt === '') $team_cp = 'team';
		$set = get_option('post_type_rules_flased_' . $team_cpt);
		if ($set !== true){
			flush_rewrite_rules(false);
			update_option('post_type_rules_flased_' . $team_cpt,true);
		}
	}
}
add_action('init', 'vt_cpt_avoid_error_posttype');

$noneed_portfolio_post = (fame_framework_active()) ? cs_get_option('noneed_portfolio_post') : '';
$noneed_case_studies_post = (fame_framework_active()) ? cs_get_option('noneed_case_studies_post') : '';
$noneed_testimonial_post = (fame_framework_active()) ? cs_get_option('noneed_testimonial_post') : '';
$noneed_team_post = (fame_framework_active()) ? cs_get_option('noneed_team_post') : '';
if (!$noneed_portfolio_post) {
	// Add Filter by Category in Portfolio Type
	add_action('restrict_manage_posts', 'fame_filter_portfolio_categories');
	function fame_filter_portfolio_categories() {
		global $typenow;
		$post_type = 'portfolio'; // Portfolio post type
		$taxonomy  = 'portfolio_category'; // Portfolio category taxonomy
		if ($typenow == $post_type) {
			$selected      = isset($_GET[$taxonomy]) ? $_GET[$taxonomy] : '';
			$info_taxonomy = get_taxonomy($taxonomy);
			wp_dropdown_categories(array(
				'show_option_all' => sprintf(esc_html__("Show All %s", 'fame-core'), $info_taxonomy->label),
				'taxonomy'        => $taxonomy,
				'name'            => $taxonomy,
				'orderby'         => 'name',
				'selected'        => $selected,
				'show_count'      => true,
				'hide_empty'      => true,
			));
		};
	}

	// Portfolio Search => ID to Term
	add_filter('parse_query', 'fame_portfolio_id_term_search');
	function fame_portfolio_id_term_search($query) {
		global $pagenow;
		$post_type = 'portfolio'; // Portfolio post type
		$taxonomy  = 'portfolio_category'; // Portfolio category taxonomy
		$q_vars    = &$query->query_vars;
		if ( $pagenow == 'edit.php' && isset($q_vars['post_type']) && $q_vars['post_type'] == $post_type && isset($q_vars[$taxonomy]) && is_numeric($q_vars[$taxonomy]) && $q_vars[$taxonomy] != 0 ) {
			$term = get_term_by('id', $q_vars[$taxonomy], $taxonomy);
			$q_vars[$taxonomy] = $term->slug;
		}
	}

	/* ---------------------------------------------------------------------------
	 * Custom columns - Portfolio
	 * --------------------------------------------------------------------------- */
	add_filter("manage_edit-portfolio_columns", "fame_portfolio_edit_columns");
	function fame_portfolio_edit_columns($columns) {
	  $new_columns['cb'] = '<input type="checkbox" />';
	  $new_columns['title'] = __('Title', 'fame-core' );
	  $new_columns['thumbnail'] = __('Image', 'fame-core' );
	  $new_columns['portfolio_category'] = __('Categories', 'fame-core' );
	  $new_columns['portfolio_order'] = __('Order', 'fame-core' );
	  $new_columns['date'] = __('Date', 'fame-core' );

	  return $new_columns;
	}
	add_action('manage_portfolio_posts_custom_column', 'fame_manage_portfolio_columns', 10, 2);
	function fame_manage_portfolio_columns( $column_name ) {
	  global $post;

	  switch ($column_name) {

	    /* If displaying the 'Image' column. */
	    case 'thumbnail':
	      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
	    break;

	    /* If displaying the 'Categories' column. */
	    case 'portfolio_category' :

	      $terms = get_the_terms( $post->ID, 'portfolio_category' );

	      if ( !empty( $terms ) ) {

	        $out = array();
	        foreach ( $terms as $term ) {
	            $out[] = sprintf( '<a href="%s">%s</a>',
	            	esc_url( add_query_arg( array( 'post_type' => $post->post_type, 'portfolio_category' => $term->slug ), 'edit.php' ) ),
	            	esc_html( sanitize_term_field( 'name', $term->name, $term->term_id, 'portfolio_category', 'display' ) )
	            );
	        }
	        /* Join the terms, separating them with a comma. */
	        echo join( ', ', $out );
	      }

	      /* If no terms were found, output a default message. */
	      else {
	        echo '&macr;';
	      }

	    break;

	    case "portfolio_order":
	      echo $post->menu_order;
	    break;

	    /* Just break out of the switch statement for everything else. */
	    default :
	      break;
	    break;

	  }
	}

}

if (!$noneed_case_studies_post) {
	// Add Filter by Category in Case Studies Type
	add_action('restrict_manage_posts', 'fame_filter_case_studies_categories');
	function fame_filter_case_studies_categories() {
		global $typenow;
		$post_type = 'casestudies'; // Case Studies post type
		$taxonomy  = 'casestudies_category'; // Case Studies category taxonomy
		if ($typenow == $post_type) {
			$selected      = isset($_GET[$taxonomy]) ? $_GET[$taxonomy] : '';
			$info_taxonomy = get_taxonomy($taxonomy);
			wp_dropdown_categories(array(
				'show_option_all' => sprintf(esc_html__("Show All %s", 'fame-core'), $info_taxonomy->label),
				'taxonomy'        => $taxonomy,
				'name'            => $taxonomy,
				'orderby'         => 'name',
				'selected'        => $selected,
				'show_count'      => true,
				'hide_empty'      => true,
			));
		};
	}

	// Case Studies Search => ID to Term
	add_filter('parse_query', 'fame_case_studies_id_term_search');
	function fame_case_studies_id_term_search($query) {
		global $pagenow;
		$post_type = 'casestudies'; // Case Studies post type
		$taxonomy  = 'casestudies_category'; // Case Studies category taxonomy
		$q_vars    = &$query->query_vars;
		if ( $pagenow == 'edit.php' && isset($q_vars['post_type']) && $q_vars['post_type'] == $post_type && isset($q_vars[$taxonomy]) && is_numeric($q_vars[$taxonomy]) && $q_vars[$taxonomy] != 0 ) {
			$term = get_term_by('id', $q_vars[$taxonomy], $taxonomy);
			$q_vars[$taxonomy] = $term->slug;
		}
	}

	/* ---------------------------------------------------------------------------
	 * Custom columns - Case Studies
	 * --------------------------------------------------------------------------- */
	add_filter("manage_edit-case_studies_columns", "fame_case_studies_edit_columns");
	function fame_case_studies_edit_columns($columns) {
	  $new_columns['cb'] = '<input type="checkbox" />';
	  $new_columns['title'] = __('Title', 'fame-core' );
	  $new_columns['thumbnail'] = __('Image', 'fame-core' );
	  $new_columns['casestudies_category'] = __('Categories', 'fame-core' );
	  $new_columns['casestudies_order'] = __('Order', 'fame-core' );
	  $new_columns['date'] = __('Date', 'fame-core' );

	  return $new_columns;
	}
	add_action('manage_case_studies_posts_custom_column', 'fame_manage_case_studies_columns', 10, 2);
	function fame_manage_case_studies_columns( $column_name ) {
	  global $post;

	  switch ($column_name) {

	    /* If displaying the 'Image' column. */
	    case 'thumbnail':
	      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
	    break;

	    /* If displaying the 'Categories' column. */
	    case 'casestudies_category' :

	      $terms = get_the_terms( $post->ID, 'casestudies_category' );

	      if ( !empty( $terms ) ) {

	        $out = array();
	        foreach ( $terms as $term ) {
	            $out[] = sprintf( '<a href="%s">%s</a>',
	            	esc_url( add_query_arg( array( 'post_type' => $post->post_type, 'casestudies_category' => $term->slug ), 'edit.php' ) ),
	            	esc_html( sanitize_term_field( 'name', $term->name, $term->term_id, 'casestudies_category', 'display' ) )
	            );
	        }
	        /* Join the terms, separating them with a comma. */
	        echo join( ', ', $out );
	      }

	      /* If no terms were found, output a default message. */
	      else {
	        echo '&macr;';
	      }

	    break;

	    case "casestudies_order":
	      echo $post->menu_order;
	    break;

	    /* Just break out of the switch statement for everything else. */
	    default :
	      break;
	    break;

	  }
	}

}

if (!$noneed_testimonial_post) {

	/* ---------------------------------------------------------------------------
	 * Custom columns - Testimonial
	 * --------------------------------------------------------------------------- */
	add_filter("manage_edit-testimonial_columns", "fame_testimonial_edit_columns");
	function fame_testimonial_edit_columns($columns) {
	  $new_columns['cb'] = '<input type="checkbox" />';
	  $new_columns['title'] = __('Title', 'fame-core' );
	  $new_columns['thumbnail'] = __('Image', 'fame-core' );
	  $new_columns['id'] = __('Testimonial ID', 'fame-core' );
	  $new_columns['testimonial_category'] = __('Category', 'fame-core' );
	  $new_columns['testimonial_order'] = __('Order', 'fame-core' );
	  $new_columns['date'] = __('Date', 'fame-core' );

	  return $new_columns;
	}

	add_action('manage_testimonial_posts_custom_column', 'fame_manage_testimonial_columns', 10, 2);
	function fame_manage_testimonial_columns( $column_name ) {
	  global $post;

	  switch ($column_name) {

	    /* If displaying the 'Image' column. */
	    case 'thumbnail':
	      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
	    break;

	    /* If displaying the 'ID' column. */
	    case 'id':
	      echo '<input type="text" onfocus="this.select();" readonly="readonly" value="'. esc_attr( $post->ID ) .'">';
	    break;

	    case "testimonial_category":
	    	$terms = get_the_terms( $post->ID, 'testimonial_category' );

	      if ( !empty( $terms ) ) {

	        $out = array();
	        foreach ( $terms as $term ) {
	            $out[] = sprintf( '<a href="%s">%s</a>',
	            	esc_url( add_query_arg( array( 'post_type' => $post->post_type, 'testimonial_category' => $term->slug ), 'edit.php' ) ),
	            	esc_html( sanitize_term_field( 'name', $term->name, $term->term_id, 'testimonial_category', 'display' ) )
	            );
	        }
	        /* Join the terms, separating them with a comma. */
	        echo join( ', ', $out );
	      }

	      /* If no terms were found, output a default message. */
	      else {
	        echo '&macr;';
	      }
	    break;

	    case "testimonial_order":
	      echo $post->menu_order;
	    break;

	    /* Just break out of the switch statement for everything else. */
	    default :
	      break;
	    break;

	  }
	}

}
if (!$noneed_team_post) {

	/* ---------------------------------------------------------------------------
	 * Custom columns - Team
	 * --------------------------------------------------------------------------- */
	add_filter("manage_edit-team_columns", "fame_team_edit_columns");
	function fame_team_edit_columns($columns) {
	  $new_columns['cb'] = '<input type="checkbox" />';
	  $new_columns['title'] = __('Title', 'fame-core' );
	  $new_columns['thumbnail'] = __('Image', 'fame-core' );
	  $new_columns['id'] = __('Member ID', 'fame-core' );
	  $new_columns['name'] = __('Job Position', 'fame-core' );
	  $new_columns['team_order'] = __('Order', 'fame-core' );
	  $new_columns['date'] = __('Date', 'fame-core' );

	  return $new_columns;
	}

	add_action('manage_team_posts_custom_column', 'fame_manage_team_columns', 10, 2);
	function fame_manage_team_columns( $column_name ) {
	  global $post;

	  switch ($column_name) {

	    /* If displaying the 'Image' column. */
	    case 'thumbnail':
	      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
	    break;

	    /* If displaying the 'ID' column. */
	    case 'id':
	      echo '<input type="text" onfocus="this.select();" readonly="readonly" value="'. esc_attr( $post->ID ) .'">';
	    break;

	    case "name":
	    	$team_options = get_post_meta( get_the_ID(), 'team_options', true );
	      echo $team_options['team_job_position'];
	    break;

	    case "team_order":
	      echo $post->menu_order;
	    break;

	    /* Just break out of the switch statement for everything else. */
	    default :
	      break;
	    break;

	  }
	}
}
